Package: multilevelmod
Title: Model Wrappers for Multi-Level Models
Version: 1.0.0
Authors@R: c(
    person("Max", "Kuhn", , "max@rstudio.com", role = c("aut"),
           comment = c(ORCID = "0000-0003-2402-136X")),
           person("Hannah", "Frick", , "hannah@rstudio.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6049-5258")),
    person("RStudio", role = c("cph", "fnd"))
  )
Description: Bindings for hierarchical regression models for use with the
    'parsnip' package. Models include longitudinal generalized linear
    models (Liang and Zeger, 1986) <doi:10.1093/biomet/73.1.13>, and
    mixed-effect models (Pinheiro and Bates)
    <doi:10.1007/978-1-4419-0318-1_1>.
License: MIT + file LICENSE
URL: https://github.com/tidymodels/multilevelmod,
        http://multilevelmod.tidymodels.org/
Depends: parsnip (>= 1.0.0), R (>= 2.10)
Imports: dplyr, lme4, purrr, rlang, tibble, withr
Suggests: covr, gee, ggplot2, knitr, nlme, rmarkdown, spelling,
        testthat, tidymodels
VignetteBuilder: knitr
Config/Needs/website: tidymodels/tidymodels, tidyverse/tidytemplate
Encoding: UTF-8
Language: en-US
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.0
Author: Max Kuhn [aut] (<https://orcid.org/0000-0003-2402-136X>),
  Hannah Frick [aut, cre] (<https://orcid.org/0000-0002-6049-5258>),
  RStudio [cph, fnd]
Maintainer: Hannah Frick <hannah@rstudio.com>
Built: R 4.4.0; ; 2024-05-08 09:38:51 UTC; unix
